//
// Entete de la classe fenetre principale
//
#ifndef FAcqGUI_h
#define FAcqGUI_h

#include "TROOT.h"
#include "TSystem.h"
#include "TCanvas.h"
#include "TGClient.h"
#include "TGButton.h"
#include "TGTextEntry.h"
#include "TGComboBox.h"
#include "TGColorSelect.h"
#include "TRootEmbeddedCanvas.h"
#include "TGSlider.h"
#include "TGListBox.h"
#include "TGNumberEntry.h"
#include "TSortedList.h"
#include "TFile.h"
#include "TTree.h"
#include "TTimer.h"
#include "TTimeStamp.h"
#include "TGTab.h"
#include "FParamCalc.h"

//#include "MGSauve.h"
#include "MTELabel.h"
#include "MCBLabel.h"
#include "MFPCManager.h"
#include "MFCondManager.h"
#include "MFPTFManager.h"
#include "MFHScaleManager.h"
//#include "MFHCtrl2DManager.h"
#ifdef READERGUI
#include "MReaderDeviceManager.h"
#endif
#include "MGAxe.h"
#ifdef NEWHISTOGUI
#include "MHistogramBuilderGUI.h"
#endif
#include "MGenericHistogramBuilderGUI.h"

#include "FEventProcessorThread.h"

#if ROOT_VERSION_CODE <= ROOT_VERSION(5,12,0)
///////////////////////////////////////////////////////////////////////////
//                                                                       //
// Input Dialog Widget  for ROOT version <= 5.12.00                                                 //
//                                                                       //
///////////////////////////////////////////////////////////////////////////

class MInputDialog : public TGTransientFrame {

  private:
    TGLabel          *fLabel;   // text entry label
    TGTextEntry      *fTE;      // text entry widget
    TGTextButton     *fOk;      // ok button
    TGTextButton     *fCancel;  // cancel button
    char             *fRetStr;  // address to store return string

  public:
    MInputDialog(const TGWindow *p = 0, const TGWindow *main = 0,
        const char *prompt =0, const char *defval = 0,
        char *retstr = 0, UInt_t options = kVerticalFrame);
    ~MInputDialog();
    virtual Bool_t ProcessMessage(Long_t msg, Long_t parm1, Long_t);

    ClassDef(MInputDialog, 0)  // Simple input dialog

};

#endif


class FAcqGUI : public TGMainFrame
{
  enum ElementId
  {
    B_Start,
    B_Pause,
    B_Continue,
    B_Stop,
    B_ClearSpectra,
    B_Sortie,
    B_CreateAndAddHisto,
    CB_varX,
    CB_varY,
    CB_varZ,
    CB_cond,
    TE_DimX,
    TE_DimY,
    TE_TitreHisto,
    TE_NomHisto,
    TE_DrawOption,
    LB_Cuts,
    B_RemoveCut,
    CB_LoadCuts,
    B_SaveCuts,
    B_NewCut,
    B_RenameCut,
    B_RetitleCut,
    B_Export,
    B_CrTGCut,
    B_EdTGCut,
    TE_Cutname
  };

  enum ActivatedColor
  {
  kActivatedColor=0xFFFFFF,
  kNotActivatedColor=0xFFDDDD
  };
  
 // Declaration des boutons de la fenetre principale
  public:
  TGPictureButton	*bRun, *bPause, *bStop, *bSortie,
                  *bClearSpectra;

  MTELabel	*nomHisto;
  MTELabel	*titreHisto;
  TGRadioButton	*isTH1;
  TGRadioButton	*isTH2;
  TGRadioButton	*isTProfile;
  TGRadioButton	*isFHScale;
  TGRadioButton	*isFHCtrl2D;
  TGRadioButton	*isFTimeHist;
  TGRadioButton	*isFTimeProfile;
  TGRadioButton	*isOscillo;
  MTELabel	*drawOption;
  MGAxe		*varX;
  MGAxe		*varY;
  MCBLabel	*varZ;
  MCBLabel	*conditions;
  //TGNumberEntry	*dimX;
  //TGNumberEntry	*minX;
  //TGNumberEntry	*maxX;
  //TGNumberEntry	*dimY;
  //TGNumberEntry	*minY;
  //TGNumberEntry	*maxY;
  TGNumberEntry	*dimZ;
  TGNumberEntry	*minZ;
  TGNumberEntry	*maxZ;
  TGLabel		*nbEvt;
  TGLabel		*runStatus;
  TTimer		*evtTimer;
  TTimeStamp		absTime;
  ULong64_t		oldNevt;
  Double_t		oldTime;
  TTimer		*refreshDSTimer;
  TGLabel		*config;
  TGTextButton	*loadConf;
  TGCheckButton	*checkSave;
  TGTextButton	*openUserDisplay;
  TGTextButton	*saveUserDisplay;
  TTimer		*refreshCanvasTimer;

  // Gestion des onglets
  TGTab 		*fTab;

  // Gestion des parametres calcules
  MFPCManager	*parCalManager;

  // Gestion des parametres calcules
  MFCondManager	*condManager;

  // Gestion des spectres echelle
  MFHScaleManager	*scaleManager;

  // Gestion des spectres de Controle 2D
  //MFHCtrl2DManager *ctrlManager;

  // Gestion des TreeFormula
  MFPTFManager *TFManager;

#ifdef READERGUI
  // Gestion des Readers et des Devices
  MReaderDeviceManager *ReDevManager;
#endif

#ifdef NEWHISTOGUI
  // fabrication d'histogrammes
  MHistogramBuilderGUI *histBuild;
#endif

  // fabrication generique d'histogrammes
  MGenericHistogramBuilderGUI *genHistBuild;

  // Gestion des coupures graphiques
  TGListBox	*listCuts;
  Int_t		firstLBid;
  Int_t		lastLBid;
  MTELabel	*enterCutName;
  MCBLabel	*mcbLoadCuts;

  // Gestion du temps de rafraichissement
  TGNumberEntry *teRefTime;

  TGLayoutHints	*lAffichageB,*lAffichageA,*lAffichageC,*lAffichageF;
  TGMatrixLayout	*matrix;
  TGCompositeFrame *cfBouton,*cfDraw,*cfCuts,*cfCutBout;
  TGColorSelect	 *colSel;

  private:
  FEventProcessorThread	*fept;

  public:
  FAcqGUI(const TGWindow *p=0,UInt_t w=2000,UInt_t h=400);
  ~FAcqGUI();

  virtual FEventProcessorThread *GetFEventProcessorThread(void)
  {return fept;}
  virtual void SetFEventProcessorThread(FEventProcessorThread *f);

  virtual void SetParams(void);
  virtual TList *GetListeOfParams(void);
  virtual FParam *GetParam(Char_t const *s);

  virtual void CreateAndAddHisto(void);

  virtual void SetListeHistos(void);
  virtual void SetSaveHistos(void);
  virtual void SaveHistos(void);
  virtual void RemoveHisto(void);
  virtual void ClearHisto(void);
  virtual void RenameHisto(void);
  virtual void RetitleHisto(void);
  virtual void ExportHisto(void);
  virtual void WriteHistoInASCIIFile(TH1 *h);
  virtual Bool_t      HandleTimer(TTimer *timer);
  virtual void AffNevt(void);

  virtual void AddParCal(char *s);
  virtual void RemParCal(char *s);
  virtual void AddCondition(char *s);
  virtual void RemCondition(char *s);

  virtual void SetHistoParams(Int_t id);
  virtual void ActivateHisto(Int_t id);
  virtual void ActivateHisto(TGFrame *f, Int_t id) { ActivateHisto(id);}
  virtual void ResetHistoParams(void);
  virtual void Hello(void);
  virtual void RebuildLists(void);

  virtual void ResetAll(void);

  virtual void StartProcessing(void);
  virtual void PauseProcessing(void);
  virtual void ClearSpectra(void);
  virtual void StopProcessing(void);
  virtual void Close(void);

  virtual void LoadConfig(void);
  virtual void SaveConfig(void);
  virtual void NewConfig(void) {Emit("NewConfig()");} // *SIGNAL*
  
  virtual void EnableAllControlButtons(void);
  virtual void DisableAllControlButtons(void);

  virtual void OpenUserDisplay(void);
  virtual void SaveUserDisplay(void);

  virtual void CreateCut(void);
  virtual void EditCuts(void);

  protected:
  virtual void PadRefresh(TPad *pad=0);
  virtual void BuildRefreshTimeWidget(void);
  public:
  virtual void SetConfigName(char *confName);
  virtual void SetCanvasRefreshTime(void);
  virtual void SetCheckBoxSaveHistos(Bool_t saveHist) { checkSave->SetOn(saveHist);}

  virtual void RefreshAllCanvases(void);
  virtual void CanSetCanvasRefreshTime(Bool_t csrt=kFALSE);
  virtual void ShowUserDisplayButtons(Bool_t sudb=kFALSE);

  virtual void WarningBox(char const *title="Warning",char const *msg="Warning");

  ClassDef(FAcqGUI,1)
};

#endif
