//
// Patron pour la generation d'une classe derivee dans ROOT
// FFileDevice derive de FDevice
//

#ifndef FFileDevice_h
#define FFileDevice_h

#define MAXREADBUFSIZE 65536

#include "FDevice.h"
#include "FIPConnection.h"

class FFileDevice : public FDevice {

  protected:
    TString fileName;

    ifstream f_in;

    UChar_t buf[MAXREADBUFSIZE];
    Int_t   bufSize;

    Int_t  nbloc;
    Double_t timeout;
    Int_t fileSize;

  protected:
    virtual void Init(void);       // initialisation

  public:
    FFileDevice(void);    // constructeur par defaut
    FFileDevice(const FFileDevice &ap); // constructeur par copie

    ~FFileDevice(void);		// desctructeur;

#if ROOT_VERSION_CODE >= ROOT_VERSION(3,4,0)
    virtual void Copy(TObject & obj) const;
#else
    virtual void Copy(TObject & obj);
#endif
    FFileDevice& operator = (const FFileDevice &hp); // operateur =

    virtual void Open(void);
    virtual void Close(void);
    virtual void Rewind(void);
    virtual void RewindAt(Int_t pos);
    virtual UChar_t *GetBuffer(Int_t &size);
    virtual Bool_t IsOk(void) {return f_in.is_open() && f_in.good();}
    virtual Bool_t IsOpen(void) {return f_in.is_open();}
    virtual Bool_t IsClosed(void) {return !f_in.is_open();}

    virtual void SetFileName(const Char_t *ser=0);
    virtual const Char_t *GetFileName(void){return fileName.Data();}
    virtual void SetBufferSize(Int_t bsize=8192){bufSize=bsize;SetChanged();}
    virtual Int_t GetBufferSize(void){return bufSize;}
    virtual void SetTimeout(Double_t tout=5.0){timeout=tout;}
    virtual void SetFileSize(Int_t size){ fileSize=size;}
    virtual Int_t GetFileSize(void){return fileSize;}

    virtual void InitFromEnv(TEnv *env);

    ClassDef(FFileDevice,1)

};

#endif

