// 
// Patron pour la generation d'une classe derivee dans ROOT
// FPage derive de TNamed
// 
 
#ifndef FPage_h 
#define FPage_h 
 
#include "Riostream.h" 
#include "TNamed.h" 
#include "FPageLayout.h"
#include "TH1.h"
#include <string>
#include <map>

using namespace std;
 
class FPage : public TNamed { 
 
   protected:
    	TList	      *listOfHistos;
	FPageLayout   *pageLayout;
	map<Int_t,string> listOfDisplays;
	
	Int_t curOptStat;
	Int_t curOptFit;
	
	Bool_t modified;
  
   protected: 
        virtual void Init(void);       // initialisation 
 
   public:	 
   	FPage(void);    // constructeur par defaut 
	FPage(const FPage &ap); // constructeur par copie 
	
	~FPage(void);		// desctructeur; 
	 
#if ROOT_VERSION_CODE >= ROOT_VERSION(3,4,0)
   	virtual void Copy(TObject & obj) const;
#else
   	virtual void Copy(TObject & obj);
#endif
	FPage& operator = (const FPage &hp); // operateur = 
 
	virtual const map<Int_t,string> *GetListOfDisplays(void)
	        {return &listOfDisplays;}
	virtual const Char_t *GetHistogramName(Int_t padNumber);
	virtual const Char_t *GetHistogramOptions(Int_t padNumber);
	virtual void AddHistogram(Int_t padNumber, const Char_t *histName);
	virtual void RemoveDisplay(Int_t padNumber);

	virtual void SetPadOptions(TPad *p,TString &opt);
	virtual void SetHistogramOptions(TH1 *h,TString &opt);
	virtual void SetLineOptions(TH1 *h,TString &opt);
	virtual void SetMarkerOptions(TH1 *h,TString &opt);
	virtual void SetFillOptions(TH1 *h,TString &opt);
	virtual void SetStatOptions(TString &opt);

	virtual void DisplayHistograms(TPad *p=(TPad *)gPad,Bool_t displayPads=kTRUE);
	 
	virtual const TList *GetListOfHistograms(void){return listOfHistos;}
	virtual void SetListOfHistograms(TList *l=0){listOfHistos=l;}
	virtual const FPageLayout *GetPageLayout(void){return pageLayout;}
	virtual void SetPageLayout(FPageLayout *pl=0) {pageLayout=pl;SetModified();}
	
	virtual void BuildPageFromPad(TPad *p=(TPad *)gPad);
	virtual Bool_t IsModified(void) {return modified;}
	virtual void SetModified(Bool_t mod=kTRUE) {modified=mod;}

 	virtual void WriteInFile(ofstream &fout);
 	virtual void ReadInFile(ifstream &fin,TList *lOfLayout);

 	virtual void    ls(Option_t *option="") const;

    ClassDef(FPage,1)
 
}; 
 
#endif 
 
