// 
// Patron pour la generation d'une classe derivee dans ROOT
// FPageLayout derive de TNamed
// 
 
#ifndef FPageLayout_h 
#define FPageLayout_h 
 
#include "Riostream.h" 
#include "TNamed.h" 
#include "TList.h" 
#include "TPad.h" 
 
class FPageLayout : public TNamed { 
 
   protected:
    	TList	listOfPads;
	Int_t   nbSubPads;
  
 	Bool_t modified;
  
  protected: 
        virtual void Init(void);       // initialisation 
 
   public:	 
   	FPageLayout(void);    // constructeur par defaut 
	FPageLayout(const FPageLayout &ap); // constructeur par copie 
	
	~FPageLayout(void);		// desctructeur; 
	 
#if ROOT_VERSION_CODE >= ROOT_VERSION(3,4,0)
   	virtual void Copy(TObject & obj) const;
#else
   	virtual void Copy(TObject & obj);
#endif
	FPageLayout& operator = (const FPageLayout &hp); // operateur = 
 
	virtual const TList *GetListOfPad(void){return &listOfPads;}
	virtual TPad *GetPad(const Char_t *padName)
		{return (TPad *)listOfPads.FindObject(padName);}
	virtual TPad *GetPad(Int_t i=0)
		{return (TPad *)listOfPads.At(i);}
	virtual void AddPad(TPad *p)
	        {listOfPads.Add(p);SetModified();}
	virtual void RemovePad(TPad *p)
	        {listOfPads.Remove(p);SetModified();}
	virtual void RemovePad(Int_t i)
	        {listOfPads.RemoveAt(i);SetModified();}
	virtual void BuildListFromPad(TPad *p=(TPad *)gPad, Bool_t reset=kTRUE);
	virtual void DisplayPads(TPad *p=(TPad *)gPad);
	virtual Int_t GetNumberOfPads(void) {return nbSubPads;}
	
	virtual Bool_t IsModified(void) {return modified;}
	virtual void SetModified(Bool_t mod=kTRUE) {modified=mod;}

 	virtual void WriteInFile(ofstream &fout);
 	virtual void ReadInFile(ifstream &fin);
	
 	virtual void    ls(Option_t *option="") const;

    ClassDef(FPageLayout,1)
 
}; 
 
#endif 
 
