// 
// Patron pour la generation d'une classe derivee dans ROOT
// MFPTFManager derive de TGCompositeFrame
// 
 
#ifndef MFPTFManager_h 
#define MFPTFManager_h 
 
#include "TROOT.h"
#include "TGClient.h"
#include "FEventProcessor.h" 
#include "FParamTreeFormula.h"
#include "MCBLabel.h" 
#include "MTELabel.h" 
 
class MFPTFManager : public TGCompositeFrame { 

	enum ElementId 
	{
	 CB_loTF,
	 CB_Expression,
	 B_AddTF,
	 B_RemoveTF,
	 TGN_Par    // Il faut que se soit le dernier de la liste
	};
 
   protected: 
	FEventProcessor		*fept;
	TList			*listOfTreeFormula;
	TList			*listOfCandidates;
	MCBLabel		*loTF;
	MCBLabel		*enterExpression;
	FParamTreeFormula	*currentTreeFormula;

   protected: 
        virtual void Init(void);       // initialisation 
 
   public:	 
	MFPTFManager(const TGWindow *p=0,UInt_t w=500,UInt_t h=300);
#if ROOT_VERSION_CODE <= ROOT_VERSION(5,12,0)
	MFPTFManager(const MFPTFManager &ap); // constructeur par copie 
#endif
	
	~MFPTFManager(void);		// desctructeur; 
	 
#if ROOT_VERSION_CODE >= ROOT_VERSION(3,4,0)
   	virtual void Copy(TObject & obj) const;
#else
   	virtual void Copy(TObject & obj);
#endif
	MFPTFManager& operator = (const MFPTFManager &hp); // operateur = 
 
	virtual Bool_t ProcessMessage(Long_t msg, Long_t par1, Long_t par2); 

	virtual FEventProcessor *GetFEventProcessor(void)
		{return fept;}
	virtual void SetFEventProcessor(FEventProcessor *f=0)
		{fept=f;}

	virtual void AddNewTreeFormula(void);
	virtual FParamTreeFormula *AddTreeFormula(void);
	virtual void RemoveTreeFormula(void);
	virtual void BuildListeTreeFormula(void);
	virtual void BuildListeOfCandidateFormula(void);
	virtual void SetListeTreeFormula(void);
	virtual void SetListeCandidateFormula(void);
 	virtual TList *GetListeOfTreeFormula(void);
 	virtual TList *GetListeOfCandidateFormula(void);
	virtual void SetTreeFormulaExpression(void);
	virtual void NewTreeFormula(char* s) {Emit("NewTreeFormula(char*)",s);} // *SIGNAL*
	virtual void RemTreeFormula(char* s) {Emit("RemTreeFormula(char*)",s);} // *SIGNAL*
	virtual void Reset(void);
	virtual void WarningBox(char const *title="Warning",char const *msg="Warning");

    ClassDef(MFPTFManager,1)
 
}; 
 
#endif 
 
